package main

import (
	"encoding/json"
	"os"
	"sync"
)

type Store struct {
	fm   sync.Mutex
	path string
}

func NewStore(path string) *Store {
	return &Store{
		path: path,
	}
}

func (s *Store) Update(plugins []*Plugin) error {
	s.fm.Lock()
	defer s.fm.Unlock()

	serializedPlugins, err := json.Marshal(plugins)
	if err != nil {
		return err
	}

	if err := os.WriteFile(s.path, serializedPlugins, 0600); err != nil {
		return err
	}
	return nil
}

func (s *Store) GetAll() ([]*Plugin, error) {
	s.fm.Lock()
	defer s.fm.Unlock()

	var plugins []*Plugin

	j, err := os.ReadFile(s.path)
	if err != nil {
		return nil, err
	}

	if err := json.Unmarshal(j, &plugins); err != nil {
		return nil, err
	}

	return plugins, nil
}
